@@ -4,11 +4,10 @@ from __future__ import annotations
 
 import re
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Callable
 
 import pytest
-from griffe.collections import ModulesCollection
-from griffe.tests import temporary_visited_module
+from griffe import ModulesCollection, temporary_visited_module
 
 from mkdocstrings_handlers.python import rendering
 
@@ -23,14 +22,22 @@ if TYPE_CHECKING:
         "aaaaa(bbbbb, ccccc=1) + ddddd.eeeee[ffff] or {ggggg: hhhhh, iiiii: jjjjj}",
     ],
 )
-def test_format_code(code: str) -> None:
-    """Assert code can be Black-formatted.
+@pytest.mark.parametrize(
+    "formatter",
+    [
+        rendering._get_black_formatter(),
+        rendering._get_ruff_formatter(),
+        rendering._get_formatter(),
+    ],
+)
+def test_format_code(code: str, formatter: Callable[[str, int], str]) -> None:
+    """Assert code can be formatted.
 
     Parameters:
         code: Code to format.
     """
     for length in (5, 100):
-        assert rendering.do_format_code(code, length)
+        assert formatter(code, length)
 
 
 @pytest.mark.parametrize(
@@ -38,7 +45,7 @@ def test_format_code(code: str) -> None:
     [("Class.method", "(param: str = 'hello') -> 'OtherClass'")],
 )
 def test_format_signature(name: Markup, signature: str) -> None:
-    """Assert signatures can be Black-formatted.
+    """Assert signatures can be formatted.
 
     Parameters:
         signature: Signature to format.
@@ -136,14 +143,14 @@ def test_filter_inherited_members(
 @pytest.mark.parametrize(
     ("order", "members_list", "expected_names"),
     [
-        (rendering.Order.alphabetical, None, ["a", "b", "c"]),
-        (rendering.Order.source, None, ["c", "b", "a"]),
-        (rendering.Order.alphabetical, ["c", "b"], ["c", "b"]),
-        (rendering.Order.source, ["a", "c"], ["a", "c"]),
-        (rendering.Order.alphabetical, [], ["a", "b", "c"]),
-        (rendering.Order.source, [], ["c", "b", "a"]),
-        (rendering.Order.alphabetical, True, ["a", "b", "c"]),
-        (rendering.Order.source, False, ["c", "b", "a"]),
+        ("alphabetical", None, ["a", "b", "c"]),
+        ("source", None, ["c", "b", "a"]),
+        ("alphabetical", ["c", "b"], ["c", "b"]),
+        ("source", ["a", "c"], ["a", "c"]),
+        ("alphabetical", [], ["a", "b", "c"]),
+        ("source", [], ["c", "b", "a"]),
+        ("alphabetical", True, ["a", "b", "c"]),
+        ("source", False, ["c", "b", "a"]),
     ],
 )
 def test_ordering_members(order: rendering.Order, members_list: list[str | None], expected_names: list[str]) -> None:
@@ -156,10 +163,12 @@ def test_ordering_members(order: rendering.Order, members_list: list[str | None]
     """
 
     class Obj:
-        def __init__(self, name: str, lineno: int | None = None) -> None:
+        def __init__(self, name: str, lineno: int | None = None, *, is_alias: bool = False) -> None:
             self.name = name
             self.lineno = lineno
+            self.alias_lineno = lineno
+            self.is_alias = is_alias
 
-    members = [Obj("a", 10), Obj("b", 9), Obj("c", 8)]
+    members = [Obj("a", 10, is_alias=True), Obj("b", 9, is_alias=False), Obj("c", 8, is_alias=True)]
     ordered = rendering.do_order_members(members, order, members_list)  # type: ignore[arg-type]
     assert [obj.name for obj in ordered] == expected_names
